.. -*- coding: utf-8 -*-

=================================
``pybill.lib.xmlwriters`` package
=================================

.. automodule:: pybill.lib.xmlwriters

``accdoc`` module
=================

.. automodule:: pybill.lib.xmlwriters.accdoc

``utils`` module
================

.. automodule:: pybill.lib.xmlwriters.utils

``accdoc_format_1_0`` module
============================

.. automodule:: pybill.lib.xmlwriters.accdoc_format_1_0
